@@ -1,14 +1,14 @@
 """Module contains code for generating tasks and constructing a DAG"""
-from datetime import timedelta, datetime
-from typing import Any, Callable, Dict, List, Union
-
+# pylint: disable=ungrouped-imports
 import os
 from copy import deepcopy
+from datetime import datetime, timedelta
+from typing import Any, Callable, Dict, List, Union
 
 from airflow import DAG, configuration
-from airflow.models import Variable
-from airflow.models import BaseOperator
+from airflow.models import BaseOperator, Variable
 from airflow.utils.module_loading import import_string
+from packaging import version
 
 try:
     from airflow.version import version as AIRFLOW_VERSION
@@ -17,9 +17,9 @@ except ImportError:
 
 # python operators were moved in 2.4
 try:
-    from airflow.operators.python import PythonOperator, BranchPythonOperator
+    from airflow.operators.python import BranchPythonOperator, PythonOperator
 except ImportError:
-    from airflow.operators.python_operator import PythonOperator, BranchPythonOperator
+    from airflow.operators.python_operator import BranchPythonOperator, PythonOperator
 
 
 # http sensor was moved in 2.4
@@ -36,11 +36,21 @@ except ImportError:
 
 # kubernetes operator
 try:
+    if version.parse(AIRFLOW_VERSION) >= version.parse("2.5.0"):
+        from kubernetes.client.models import V1ContainerPort as Port
+        from kubernetes.client.models import (
+            V1EnvVar,
+            V1EnvVarSource,
+            V1ObjectFieldSelector,
+            V1Volume,
+        )
+        from kubernetes.client.models import V1VolumeMount as VolumeMount
+    else:
+        from airflow.kubernetes.pod import Port
+        from airflow.kubernetes.volume_mount import VolumeMount
+        from airflow.kubernetes.volume import Volume
+        from airflow.kubernetes.pod_runtime_info_env import PodRuntimeInfoEnv
     from airflow.kubernetes.secret import Secret
-    from airflow.kubernetes.pod import Port
-    from airflow.kubernetes.volume_mount import VolumeMount
-    from airflow.kubernetes.volume import Volume
-    from airflow.kubernetes.pod_runtime_info_env import PodRuntimeInfoEnv
     from airflow.providers.cncf.kubernetes.operators.kubernetes_pod import (
         KubernetesPodOperator,
     )
@@ -51,8 +61,8 @@ except ImportError:
     from airflow.contrib.kubernetes.volume import Volume
     from airflow.contrib.kubernetes.pod_runtime_info_env import PodRuntimeInfoEnv
     from airflow.contrib.operators.kubernetes_pod_operator import KubernetesPodOperator
-from kubernetes.client.models import V1Pod, V1Container
-from packaging import version
+
+from kubernetes.client.models import V1Container, V1Pod
 
 from dagfactory import utils
 
@@ -142,6 +152,12 @@ class DagBuilder:
             )
             del dag_params["default_args"]["retry_delay_sec"]
 
+        if utils.check_dict_key(dag_params["default_args"], "sla_secs"):
+            dag_params["default_args"]["sla"]: timedelta = timedelta(
+                seconds=dag_params["default_args"]["sla_secs"]
+            )
+            del dag_params["default_args"]["sla_secs"]
+
         if utils.check_dict_key(dag_params["default_args"], "sla_miss_callback"):
             if isinstance(dag_params["default_args"]["sla_miss_callback"], str):
                 dag_params["default_args"][
@@ -253,6 +269,7 @@ class DagBuilder:
             operator_obj: Callable[..., BaseOperator] = import_string(operator)
         except Exception as err:
             raise Exception(f"Failed to import operator: {operator}") from err
+        # pylint: disable=too-many-nested-blocks
         try:
             if operator_obj in [PythonOperator, BranchPythonOperator, PythonSensor]:
                 if (
@@ -364,19 +381,54 @@ class DagBuilder:
                     if task_params.get("volume_mounts") is not None
                     else None
                 )
-                task_params["volumes"] = (
-                    [Volume(**v) for v in task_params.get("volumes")]
-                    if task_params.get("volumes") is not None
-                    else None
-                )
-                task_params["pod_runtime_info_envs"] = (
-                    [
-                        PodRuntimeInfoEnv(**v)
-                        for v in task_params.get("pod_runtime_info_envs")
-                    ]
-                    if task_params.get("pod_runtime_info_envs") is not None
-                    else None
-                )
+                if version.parse(AIRFLOW_VERSION) >= version.parse("2.5.0"):
+                    if task_params.get("volumes") is not None:
+                        task_params_volumes = []
+                        for vol in task_params.get("volumes"):
+                            resp = V1Volume(name=vol.get("name"))
+                            for k, v in vol["configs"].items():
+                                snake_key = utils.convert_to_snake_case(k)
+                                if hasattr(resp, snake_key):
+                                    setattr(resp, snake_key, v)
+                                else:
+                                    raise Exception(
+                                        f"Volume for KubernetesPodOperator \
+                                        does not have attribute {k}"
+                                    )
+                            task_params_volumes.append(resp)
+                        task_params["volumes"] = task_params_volumes
+                    else:
+                        task_params["volumes"] = None
+
+                    task_params["pod_runtime_info_envs"] = (
+                        [
+                            V1EnvVar(
+                                name=v.get("name"),
+                                value_from=V1EnvVarSource(
+                                    field_ref=V1ObjectFieldSelector(
+                                        field_path=v.get("field_path")
+                                    )
+                                ),
+                            )
+                            for v in task_params.get("pod_runtime_info_envs")
+                        ]
+                        if task_params.get("pod_runtime_info_envs") is not None
+                        else None
+                    )
+                else:
+                    task_params["volumes"] = (
+                        [Volume(**v) for v in task_params.get("volumes")]
+                        if task_params.get("volumes") is not None
+                        else None
+                    )
+                    task_params["pod_runtime_info_envs"] = (
+                        [
+                            PodRuntimeInfoEnv(**v)
+                            for v in task_params.get("pod_runtime_info_envs")
+                        ]
+                        if task_params.get("pod_runtime_info_envs") is not None
+                        else None
+                    )
                 task_params["full_pod_spec"] = (
                     V1Pod(**task_params.get("full_pod_spec"))
                     if task_params.get("full_pod_spec") is not None
